@@ -131,6 +131,7 @@ static MAKE_GET_IDX(dive_site_table, struct dive_site *, dive_sites)
 MAKE_SORT(dive_site_table, struct dive_site *, dive_sites, compare_sites)
 static MAKE_REMOVE(dive_site_table, struct dive_site *, dive_site)
 MAKE_CLEAR_TABLE(dive_site_table, dive_sites, dive_site)
+MAKE_MOVE_TABLE(dive_site_table, dive_sites)
 
 int add_dive_site_to_table(struct dive_site *ds, struct dive_site_table *ds_table)
 {
@@ -170,6 +171,21 @@ struct dive_site *alloc_dive_site()
 	return ds;
 }
 
+struct dive_site *alloc_dive_site_with_name(const char *name)
+{
+	struct dive_site *ds = alloc_dive_site();
+	ds->name = copy_string(name);
+	return ds;
+}
+
+struct dive_site *alloc_dive_site_with_gps(const char *name, const location_t *loc)
+{
+	struct dive_site *ds = alloc_dive_site_with_name(name);
+	ds->location = *loc;
+
+	return ds;
+}
+
 /* when parsing, dive sites are identified by uuid */
 struct dive_site *alloc_or_get_dive_site(uint32_t uuid, struct dive_site_table *ds_table)
 {
@@ -191,13 +207,10 @@ int nr_of_dives_at_dive_site(struct dive_site *ds)
 	return ds->dives.nr;
 }
 
-bool is_dive_site_used(struct dive_site *ds, bool select_only)
+bool is_dive_site_selected(struct dive_site *ds)
 {
 	int i;
 
-	if (!select_only)
-		return ds->dives.nr > 0;
-
 	for (i = 0; i < ds->dives.nr; i++) {
 		if (ds->dives.dives[i]->selected)
 			return true;
@@ -233,8 +246,7 @@ void delete_dive_site(struct dive_site *ds, struct dive_site_table *ds_table)
 /* allocate a new site and add it to the table */
 struct dive_site *create_dive_site(const char *name, struct dive_site_table *ds_table)
 {
-	struct dive_site *ds = alloc_dive_site();
-	ds->name = copy_string(name);
+	struct dive_site *ds = alloc_dive_site_with_name(name);
 	add_dive_site_to_table(ds, ds_table);
 	return ds;
 }
@@ -242,11 +254,8 @@ struct dive_site *create_dive_site(const char *name, struct dive_site_table *ds_
 /* same as before, but with GPS data */
 struct dive_site *create_dive_site_with_gps(const char *name, const location_t *loc, struct dive_site_table *ds_table)
 {
-	struct dive_site *ds = alloc_dive_site();
-	ds->name = copy_string(name);
-	ds->location = *loc;
+	struct dive_site *ds = alloc_dive_site_with_gps(name, loc);
 	add_dive_site_to_table(ds, ds_table);
-
 	return ds;
 }
 
