@@ -6,7 +6,7 @@
 extern "C" {
 #endif
 
-void populate_pressure_information(struct dive *, struct divecomputer *, struct plot_info *, int);
+void populate_pressure_information(const struct dive *, const struct divecomputer *, struct plot_info *, int);
 
 #ifdef __cplusplus
 }
