@@ -5,7 +5,9 @@
 #endif
 
 #include "ssrf.h"
+#include "dive.h"
 #include "divesite.h"
+#include "sample.h"
 #include "subsurface-string.h"
 #include "parse.h"
 #include "divelist.h"
@@ -389,7 +391,8 @@ static int divinglog_dive(void *param, int columns, char **data, char **column)
 
 
 int parse_divinglog_buffer(sqlite3 *handle, const char *url, const char *buffer, int size,
-			    struct dive_table *table, struct trip_table *trips, struct dive_site_table *sites)
+			    struct dive_table *table, struct trip_table *trips, struct dive_site_table *sites,
+			    struct device_table *devices)
 {
 	UNUSED(buffer);
 	UNUSED(size);
@@ -401,6 +404,7 @@ int parse_divinglog_buffer(sqlite3 *handle, const char *url, const char *buffer,
 	state.target_table = table;
 	state.trips = trips;
 	state.sites = sites;
+	state.devices = devices;
 	state.sql_handle = handle;
 
 	char get_dives[] = "select Number,strftime('%s',Divedate || ' ' || ifnull(Entrytime,'00:00')),Country || ' - ' || City || ' - ' || Place,Buddy,Comments,Depth,Divetime,Divemaster,Airtemp,Watertemp,Weight,Divesuit,Computer,ID,Visibility,SupplyType from Logbook where UUID not in (select UUID from DeletedRecords)";
