@@ -1,5 +1,6 @@
 // SPDX-License-Identifier: GPL-2.0
 #include <QFileDialog>
+#include <QProgressDialog>
 #include <QShortcut>
 #include <QSettings>
 #include <string.h> // Allows string comparisons and substitutions in TeX export
@@ -14,6 +15,7 @@
 #include "core/divesite.h"
 #include "core/errorhelper.h"
 #include "core/file.h"
+#include "core/gettextfromc.h"
 #include "core/tag.h"
 #include "backend-shared/exportfuncs.h"
 #include "desktop-widgets/mainwindow.h"
@@ -131,6 +133,32 @@ void DiveLogExportDialog::on_exportGroup_buttonClicked(QAbstractButton*)
 	showExplanation();
 }
 
+// Use a QProgressDialog to show export-progress
+// Default implementation of the export callback: do nothing / never cancel
+struct ProgressDialogCallback : public ExportCallback {
+	ProgressDialogCallback();
+	QProgressDialog dialog;
+	virtual void setProgress(int progress) override;
+	virtual bool canceled() const override;
+};
+
+ProgressDialogCallback::ProgressDialogCallback() :
+	dialog(gettextFromC::tr("Exporting..."), gettextFromC::tr("Cancel"), 0, 1000, MainWindow::instance())
+{
+	dialog.setWindowModality(Qt::WindowModal);
+	dialog.setMinimumDuration(0); // Show dialog immediately
+}
+
+void ProgressDialogCallback::setProgress(int progress)
+{
+	dialog.setValue(progress);
+}
+
+bool ProgressDialogCallback::canceled() const
+{
+	return dialog.wasCanceled();
+}
+
 void DiveLogExportDialog::on_buttonBox_accepted()
 {
 	QString filename;
@@ -161,12 +189,12 @@ void DiveLogExportDialog::on_buttonBox_accepted()
 		} else if (ui->exportWorldMap->isChecked()) {
 			filename = QFileDialog::getSaveFileName(this, tr("Export world map"), lastDir,
 								tr("HTML files") + " (*.html)");
-			if (!filename.isNull() && !filename.isEmpty())
+			if (!filename.isEmpty())
 				export_worldmap_HTML(qPrintable(filename), ui->exportSelected->isChecked());
 		} else if (ui->exportSubsurfaceXML->isChecked()) {
 			filename = QFileDialog::getSaveFileName(this, tr("Export Subsurface XML"), lastDir,
 								tr("Subsurface files") + " (*.ssrf *.xml)");
-			if (!filename.isNull() && !filename.isEmpty()) {
+			if (!filename.isEmpty()) {
 				if (!filename.contains('.'))
 					filename.append(".ssrf");
 				QByteArray bt = QFile::encodeName(filename);
@@ -175,7 +203,7 @@ void DiveLogExportDialog::on_buttonBox_accepted()
 		} else if (ui->exportSubsurfaceSitesXML->isChecked()) {
 			filename = QFileDialog::getSaveFileName(this, tr("Export Subsurface dive sites XML"), lastDir,
 								tr("Subsurface files") + " (*.xml)");
-			if (!filename.isNull() && !filename.isEmpty()) {
+			if (!filename.isEmpty()) {
 				if (!filename.contains('.'))
 					filename.append(".xml");
 				QByteArray bt = QFile::encodeName(filename);
@@ -184,31 +212,35 @@ void DiveLogExportDialog::on_buttonBox_accepted()
 			}
 		} else if (ui->exportImageDepths->isChecked()) {
 			filename = QFileDialog::getSaveFileName(this, tr("Save image depths"), lastDir);
-			if (!filename.isNull() && !filename.isEmpty())
+			if (!filename.isEmpty())
 				export_depths(qPrintable(filename), ui->exportSelected->isChecked());
 		} else if (ui->exportTeX->isChecked() || ui->exportLaTeX->isChecked()) {
 			filename = QFileDialog::getSaveFileName(this, tr("Export to TeX file"), lastDir, tr("TeX files") + " (*.tex)");
-			if (!filename.isNull() && !filename.isEmpty())
-				export_TeX(qPrintable(filename), ui->exportSelected->isChecked(), ui->exportTeX->isChecked());
+			if (!filename.isEmpty()) {
+				ProgressDialogCallback cb;
+				export_TeX(qPrintable(filename), ui->exportSelected->isChecked(), ui->exportTeX->isChecked(), cb);
+			}
 		} else if (ui->exportProfile->isChecked()) {
 			filename = QFileDialog::getSaveFileName(this, tr("Save profile image"), lastDir);
-			if (!filename.isNull() && !filename.isEmpty())
-				exportProfile(qPrintable(filename), ui->exportSelected->isChecked());
+			if (!filename.isEmpty()) {
+				ProgressDialogCallback cb;
+				exportProfile(qPrintable(filename), ui->exportSelected->isChecked(), cb);
+			}
 		} else if (ui->exportProfileData->isChecked()) {
 			filename = QFileDialog::getSaveFileName(this, tr("Save profile data"), lastDir);
-			if (!filename.isNull() && !filename.isEmpty())
+			if (!filename.isEmpty())
 				save_profiledata(qPrintable(filename), ui->exportSelected->isChecked());
 		}
 		break;
 	case 1:
 		filename = QFileDialog::getSaveFileName(this, tr("Export HTML files as"), lastDir,
 							tr("HTML files") + " (*.html)");
-		if (!filename.isNull() && !filename.isEmpty())
+		if (!filename.isEmpty())
 			exportHtmlInit(filename);
 		break;
 	}
 
-	if (!filename.isNull() && !filename.isEmpty()) {
+	if (!filename.isEmpty()) {
 		// remember the last export path
 		QFileInfo fileInfo(filename);
 		qPrefDisplay::set_lastDir(fileInfo.dir().path());
@@ -229,7 +261,7 @@ void exportProfile(const struct dive *dive, const QString filename)
 	profile->setPrintMode(true);
 	double scale = profile->getFontPrintScale();
 	profile->setFontPrintScale(4 * scale);
-	profile->plotDive(dive, true, false, true);
+	profile->plotDive(dive, 0, false, true);
 	QImage image = QImage(profile->size() * 4, QImage::Format_RGB32);
 	QPainter paint;
 	paint.begin(&image);
@@ -238,5 +270,5 @@ void exportProfile(const struct dive *dive, const QString filename)
 	profile->setToolTipVisibile(true);
 	profile->setFontPrintScale(scale);
 	profile->setPrintMode(false);
-	profile->plotDive(dive, true);
+	profile->plotDive(dive, 0); // TODO: Shouldn't this plot the current dive?
 }
