@@ -374,6 +374,7 @@ void MainWindow::enableDisableCloudActions()
 void MainWindow::enableDisableOtherDCsActions()
 {
 	bool nr = number_of_computers(current_dive) > 1;
+	enableShortcuts();
 	ui.actionNextDC->setEnabled(nr);
 	ui.actionPreviousDC->setEnabled(nr);
 }
@@ -1512,7 +1513,7 @@ void MainWindow::on_actionImportDiveSites_triggered()
 void MainWindow::editCurrentDive()
 {
 	// We only allow editing of the profile for manually added dives.
-	if (!current_dive || !same_string(current_dive->dc.model, "manually added dive") || !userMayChangeAppState())
+	if (!current_dive || (!same_string(current_dive->dc.model, "manually added dive") && current_dive->dc.samples) || !userMayChangeAppState())
 		return;
 
 	// This shouldn't be possible, but let's make sure no weird "double editing" takes place.
@@ -1523,7 +1524,7 @@ void MainWindow::editCurrentDive()
 	copy_dive(current_dive, &displayed_dive); // Work on a copy of the dive
 	DivePlannerPointsModel::instance()->setPlanMode(DivePlannerPointsModel::ADD);
 	DivePlannerPointsModel::instance()->loadFromDive(&displayed_dive);
-	graphics->setAddState(&displayed_dive, 0);
+	graphics->setEditState(&displayed_dive, 0);
 	setApplicationState(ApplicationState::EditDive);
 	mainTab->enableEdition();
 }
