@@ -5,3 +5,7 @@ TabBase::TabBase(QWidget *parent) : QWidget(parent)
 {
 }
 
+void TabBase::updateUi(QString titleColor)
+{
+	Q_UNUSED(titleColor)
+}
