@@ -49,12 +49,10 @@ public:
 	void setLinesVisible(bool arg1);
 	void setLineSize(qreal lineSize);
 	void setLine(const QLineF& line);
-	int unitSystem;
 	virtual void updateTicks(color_index_t color = TIME_GRID);
 
 signals:
 	void sizeChanged();
-	void maxChanged();
 
 protected:
 	ProfileWidget2 *profileWidget;
@@ -82,7 +80,7 @@ public:
 private:
 	QString textForValue(double value) const override;
 	QColor colorForValue(double value) const override;
-	int unitSystem;
+	units::LENGTH unitSystem;
 private
 slots:
 	void settingsChanged();
