@@ -4,19 +4,20 @@
 #include "profile-widget/divecartesianaxis.h"
 #include "profile-widget/animationfunctions.h"
 #include "core/event.h"
+#include "core/format.h"
 #include "core/libdivecomputer.h"
 #include "core/profile.h"
 #include "core/gettextfromc.h"
 #include "core/metrics.h"
-#include "core/membuffer.h"
 #include "core/sample.h"
 #include "core/subsurface-string.h"
+#include <QDebug>
 
 #define DEPTH_NOT_FOUND (-2342)
 
 DiveEventItem::DiveEventItem(const struct dive *d, struct event *ev, struct gasmix lastgasmix,
 			     DivePlotDataModel *model, DiveCartesianAxis *hAxis, DiveCartesianAxis *vAxis,
-			     int speed, QGraphicsItem *parent) : DivePixmapItem(parent),
+			     int speed, double fontPrintScale, QGraphicsItem *parent) : DivePixmapItem(parent),
 	vAxis(vAxis),
 	hAxis(hAxis),
 	dataModel(model),
@@ -25,7 +26,7 @@ DiveEventItem::DiveEventItem(const struct dive *d, struct event *ev, struct gasm
 {
 	setFlag(ItemIgnoresTransformations);
 
-	setupPixmap(lastgasmix);
+	setupPixmap(lastgasmix, fontPrintScale);
 	setupToolTipString(lastgasmix);
 	recalculatePos(0);
 
@@ -48,8 +49,9 @@ struct event *DiveEventItem::getEventMutable()
 	return ev;
 }
 
-void DiveEventItem::setupPixmap(struct gasmix lastgasmix)
+void DiveEventItem::setupPixmap(struct gasmix lastgasmix, double fontPrintScale)
 {
+	extern int verbose;
 	const IconMetrics& metrics = defaultIconMetrics();
 #ifndef SUBSURFACE_MOBILE
 	int sz_bigger = metrics.sz_med + metrics.sz_small; // ex 40px
@@ -63,7 +65,10 @@ void DiveEventItem::setupPixmap(struct gasmix lastgasmix)
 	int sz_bigger = metrics.sz_big + metrics.sz_med;
 #endif
 #endif
+	sz_bigger = lrint(sz_bigger * fontPrintScale);
 	int sz_pix = sz_bigger/2; // ex 20px
+	if (verbose)
+		qDebug() << __FUNCTION__ << "fontPrintScale" << fontPrintScale << "metrics" << metrics.sz_med << metrics.sz_small << "sz_bigger" << sz_bigger;
 
 #define EVENT_PIXMAP(PIX) QPixmap(QString(PIX)).scaled(sz_pix, sz_pix, Qt::KeepAspectRatio, Qt::SmoothTransformation)
 #define EVENT_PIXMAP_BIGGER(PIX) QPixmap(QString(PIX)).scaled(sz_bigger, sz_bigger, Qt::KeepAspectRatio, Qt::SmoothTransformation)
@@ -160,7 +165,6 @@ void DiveEventItem::setupToolTipString(struct gasmix lastgasmix)
 	if (event_is_gaschange(ev)) {
 		struct icd_data icd_data;
 		struct gasmix mix = get_gasmix_from_event(dive, ev);
-		struct membuffer mb = {};
 		name += ": ";
 		name += gasname(mix);
 
@@ -169,13 +173,11 @@ void DiveEventItem::setupToolTipString(struct gasmix lastgasmix)
 			name += tr(" (cyl. %1)").arg(ev->gas.index + 1);
 		bool icd = isobaric_counterdiffusion(lastgasmix, mix, &icd_data);
 		if (icd_data.dHe < 0) {
-			put_format(&mb, "\n%s %s:%+.3g%% %s:%+.3g%%%s%+.3g%%",
-				qPrintable(tr("ICD")),
-				qPrintable(tr("ΔHe")), icd_data.dHe / 10.0,
-				qPrintable(tr("ΔN₂")), icd_data.dN2 / 10.0,
-				icd ? ">" : "<", lrint(-icd_data.dHe / 5.0) / 10.0);
-			name += QString::fromUtf8(mb.buffer, mb.len);
-			free_buffer(&mb);
+			name += qasprintf_loc("\n%s %s:%+.3g%% %s:%+.3g%%%s%+.3g%%",
+					      qPrintable(tr("ICD")),
+					      qPrintable(tr("ΔHe")), icd_data.dHe / 10.0,
+					      qPrintable(tr("ΔN₂")), icd_data.dN2 / 10.0,
+					      icd ? ">" : "<", lrint(-icd_data.dHe / 5.0) / 10.0);
 		}
 	} else if (same_string(ev->name, "modechange")) {
 		name += QString(": %1").arg(gettextFromC::tr(divemode_text_ui[ev->value]));
