@@ -4,14 +4,10 @@
 #include "core/pref.h"
 #include "core/qthelper.h"
 #include "core/settings/qPrefDisplay.h"
-#ifndef SUBSURFACE_MOBILE
-#include "desktop-widgets/preferences/preferencesdialog.h"
-#include "core/dive.h" // for displayed_dive
-#include "commands/command.h"
-#endif
+#include "core/subsurface-qt/divelistnotifier.h"
 
 #include <QDesktopServices>
-#include <QGraphicsView>
+#include <QPen>
 #include <QUrl>
 #include <QGraphicsSceneMouseEvent>
 
@@ -28,17 +24,7 @@ CloseButtonItem::CloseButtonItem(QGraphicsItem *parent): DivePixmapItem(parent)
 
 void CloseButtonItem::mousePressEvent(QGraphicsSceneMouseEvent *)
 {
-	qgraphicsitem_cast<DivePictureItem*>(parentItem())->removePicture();
-}
-
-void CloseButtonItem::hide()
-{
-	DivePixmapItem::hide();
-}
-
-void CloseButtonItem::show()
-{
-	DivePixmapItem::show();
+	emit clicked();
 }
 
 DivePictureItem::DivePictureItem(QGraphicsItem *parent): DivePixmapItem(parent),
@@ -50,9 +36,8 @@ DivePictureItem::DivePictureItem(QGraphicsItem *parent): DivePixmapItem(parent),
 	setFlag(ItemIgnoresTransformations);
 	setAcceptHoverEvents(true);
 	setScale(0.2);
-#ifndef SUBSURFACE_MOBILE
-	connect(PreferencesDialog::instance(), SIGNAL(settingsChanged()), this, SLOT(settingsChanged()));
-#endif
+	connect(&diveListNotifier, &DiveListNotifier::settingsChanged, this, &DivePictureItem::settingsChanged);
+	connect(button, &CloseButtonItem::clicked, [this] () { emit removePicture(fileUrl); });
 
 	canvas->setPen(Qt::NoPen);
 	canvas->setBrush(QColor(Qt::white));
@@ -120,12 +105,3 @@ void DivePictureItem::mousePressEvent(QGraphicsSceneMouseEvent *event)
 	if (event->button() == Qt::LeftButton)
 		QDesktopServices::openUrl(QUrl::fromLocalFile(localFilePath(fileUrl)));
 }
-
-void DivePictureItem::removePicture()
-{
-#ifndef SUBSURFACE_MOBILE
-	struct dive *d = get_dive_by_uniq_id(displayed_dive.id);
-	if (d)
-		Command::removePictures({ { d, { fileUrl.toStdString() } } });
-#endif
-}
